import * as React from "react";
import { View, StyleSheet } from "react-native";
import { useCurrentScreenData } from "@applicaster/zapp-react-native-utils/reactHooks/screen";
import { ifEmptyUseFallback } from "@applicaster/zapp-react-native-utils/cellUtils";
import { usePickFromState } from "@applicaster/zapp-react-native-redux/hooks";
import { isWeb } from "@applicaster/zapp-react-native-utils/reactUtils";
import { Spinner } from "@applicaster/zapp-react-native-ui-components/Components/Spinner";
import { useTheme } from "@applicaster/zapp-react-native-utils/theme";

import { useScreenConfiguration } from "../../River/useScreenConfiguration";

const styles = StyleSheet.create({
  container: {
    position: "absolute",
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,

    alignItems: "center",
    justifyContent: "center",
  },
});

export const TransitionOverlay = () => {
  const screen = useCurrentScreenData();

  const { backgroundColor: screenBackgroundColor } = useScreenConfiguration(
    screen?.id
  );

  const theme = useTheme();

  const themeBackgroundColor = React.useMemo(
    () => theme.app_background_color,
    [theme.app_background_color]
  );

  const backgroundColor = ifEmptyUseFallback(
    screenBackgroundColor,
    themeBackgroundColor
  );

  const {
    appState: { isTransitioning },
  } = usePickFromState(["appState"]);

  if (!isWeb() || !isTransitioning) {
    return null;
  }

  return (
    <View
      style={[
        styles.container,
        {
          backgroundColor,
        },
      ]}
    >
      <Spinner size={"large"} />
    </View>
  );
};
