import * as React from "react";
import * as R from "ramda";
import { View } from "react-native";
import { render } from "@testing-library/react-native";
import { Provider } from "react-redux";
import { createStore } from "redux";
import { NavigationContext } from "@applicaster/zapp-react-native-ui-components/Contexts/NavigationContext";

import { ThemeContext } from "@applicaster/zapp-react-native-utils/theme";

jest.mock("@applicaster/quick-brick-core/App/ActionSetters", () => ({
  useRiverInitialState: () => ({}),
}));

jest.mock("@applicaster/zapp-react-native-utils/reactHooks/screen");

const Layout = require("..").default;

const ResolvedMenuPlug = () => <View testID="resolved-menu-plug" />;

const plugins = [
  {
    module: ResolvedMenuPlug,
    type: "menu",
    name: "resolved-menu-plug",
  },
];

const bgImage = "http://applicaster.com";
const isNavBarVisible = true;

const store = createStore(() => ({
  appState: { appReady: true },
  remoteConfigurations: { sdkAssets: { bgImage } },
  plugins,
}));

describe("Layout TV", () => {
  const themes = {
    myTheme: { screen_margin_top: 10, screen_margin_bottom: 10 },
  };

  const selectedThemeId = "myTheme";

  const navigator = {
    activeRiver: {
      navigations: [{ category: "menu", navigation_type: "menu" }],
    },
    canGoBack: () => false,
    currentRoute: "/river/A1234",
    screenData: {
      navigations: [{ category: "menu", navigation_type: "menu" }],
    },
    isNavBarVisible: isNavBarVisible,
  };

  const wrapper = ({ children }) => (
    <Provider store={store}>
      <NavigationContext.Provider value={navigator}>
        <ThemeContext.Provider value={{ themes, selectedThemeId }}>
          {children}
        </ThemeContext.Provider>
      </NavigationContext.Provider>
    </Provider>
  );

  const Screen = (props) => (
    <View testID="screen-component" {...R.omit(["children"])(props)} />
  );

  const NavBar = (props) => (
    <View testID="nav-bar-component" {...R.omit(["children"])(props)} />
  );

  const Background = (props: Record<any, any>) => (
    <View testID="background-component" {...R.omit(["children"])(props)}>
      {props.children}
    </View>
  );

  const Components = {
    NavBar,
    Background,
  };

  it("renders", () => {
    const { toJSON } = render(
      <Layout Components={Components}>
        <Screen />
      </Layout>,
      { wrapper }
    );

    expect(toJSON()).toMatchSnapshot();
  });

  describe("props passed to background component", () => {
    it("passes correct props", () => {
      const { getByTestId } = render(
        <Layout
          Components={Components}
          ComponentsExtraProps={{
            Background: { testProp: true },
          }}
        >
          <Screen />
        </Layout>,
        { wrapper }
      );

      const bgComponent = getByTestId("background-component");
      expect(bgComponent.props.backgroundImageUrl).toBe(bgImage);
      expect(bgComponent.props.testProp).toBe(true);
    });
  });
});
