import React, { PropsWithChildren } from "react";
import { ImageBackground } from "react-native";

import { imageSrcFromMediaItem } from "@applicaster/zapp-react-native-utils/configurationUtils";

type Props = PropsWithChildren<{
  entry: ZappEntry;
  style?: { [K: string]: any };
  imageStyle?: { [K: string]: any };
  imageKey?: string;
}>;

const PlayerImageBackgroundComponent = ({
  entry,
  children,
  style,
  imageStyle,
  imageKey,
}: Props) => {
  const source = React.useMemo(
    () => ({ uri: imageSrcFromMediaItem(entry, imageKey) }),
    [imageKey, entry]
  );

  if (!source) return <>{children}</>;

  return (
    <ImageBackground
      resizeMode="cover"
      style={style}
      imageStyle={imageStyle}
      source={source}
    >
      {children}
    </ImageBackground>
  );
};

export const PlayerImageBackground = React.memo(PlayerImageBackgroundComponent);
