import {
  useNavigation,
  useNavigationType,
  MenuTypes,
  useGetBottomTabBarHeight,
} from "@applicaster/zapp-react-native-utils/reactHooks";
import { useSafeAreaInsets } from "react-native-safe-area-context";
import { isMenuVisible } from "@applicaster/zapp-react-native-ui-components/Components/Screen/navigationHandler";

import { useConfiguration } from "../utils";

type Option<T> = T | undefined;

type Return = {
  top: Option<number>;
  height: Option<number>;
  bottom: Option<number>;
};

export const usePosition = (): Return => {
  const { minimised_height: minimisedHeight } = useConfiguration();
  const insets = useSafeAreaInsets();
  const bottomTabBarHeight = useGetBottomTabBarHeight();

  const {
    videoModalState: { mode },
    currentRoute,
    screenData,
  } = useNavigation();

  const docked = mode === "MINIMIZED";

  const navType = useNavigationType();
  const isBottomBarNavigation = navType === MenuTypes.bottomTabBar;

  const minimisedMarginBottom =
    isMenuVisible(currentRoute, screenData) && isBottomBarNavigation
      ? bottomTabBarHeight
      : insets.bottom;

  if (docked) {
    return {
      top: undefined,
      height: minimisedHeight,
      bottom: minimisedMarginBottom,
    };
  }

  return { top: 0, height: undefined, bottom: 0 };
};
